/// <reference types="node" />
import type { Compiler, RspackPluginInstance, Target } from '@rspack/core';
export interface DotenvPluginOptions {
    /**
     * The path to your environment variables.
     * @default './.env'.
     */
    path?: string;
    /**
     * If `false` ignore safe-mode, if `true` load `'./.env.example'`, if a `string` load that file as the sample.
     * @default false
     */
    safe?: boolean | string;
    /**
     * Whether to allow empty strings in safe mode.
     * If false, will throw an error if any env variables are empty (but only if safe mode is enabled).
     * @default false
     */
    allowEmptyValues?: boolean;
    /**
     * Set to `true` if you would rather load all system variables as well (useful for CI purposes).
     * @default false
     */
    systemvars?: boolean;
    /**
     * If `true`, all warnings will be surpressed.
     * @default false
     */
    silent?: boolean;
    /**
     * Allows your variables to be "expanded" for reusability within your .env file.
     * @default false
     */
    expand?: boolean;
    /**
     * Adds support for dotenv-defaults. If set to `true`, uses `./.env.defaults`. If a `string`, uses that location for a defaults file.
     * Read more at {@link https://www.npmjs.com/package/dotenv-defaults}.
     * @default false
     */
    defaults?: boolean | string;
    /**
     * Override the automatic check whether to stub `process.env`.
     * @dfault false
     */
    ignoreStub?: boolean;
    /**
     * The prefix to use before the name of your env variables.
     * @default 'process.env.'
     */
    prefix?: string;
}
export declare class DotenvPlugin implements RspackPluginInstance {
    private config;
    constructor(options?: DotenvPluginOptions);
    apply(compiler: Compiler): void;
    gatherVariables(): {
        [x: string]: string | undefined;
        TZ?: string | undefined;
    };
    initializeVars(): {
        [x: string]: string | undefined;
        TZ?: string | undefined;
    };
    getEnvs(): {
        env: import("dotenv").DotenvParseOutput;
        blueprint: import("dotenv").DotenvParseOutput;
    };
    getDefaults(): string;
    formatData(variables: NodeJS.ProcessEnv, target: Target): Record<string, string>;
    shouldStub(targetInput: Target): boolean;
    loadFile(file: string, silent?: boolean): string;
    warn(msg: string, silent?: boolean): void;
}
